@@ -249,7 +249,10 @@ def process(
                     else:
                         code_sorting_section += line
                         line = ""
-                elif stripped_line in config.section_comments:
+                elif (
+                    stripped_line in config.section_comments
+                    or stripped_line in config.section_comments_end
+                ):
                     if import_section and not contains_imports:
                         output_stream.write(import_section)
                         import_section = line
@@ -353,7 +356,7 @@ def process(
                 next_import_section = ""
 
             if import_section:
-                if add_imports and not indent:
+                if add_imports and (contains_imports or not config.append_only) and not indent:
                     import_section = (
                         line_separator.join(add_imports) + line_separator + import_section
                     )
@@ -460,6 +463,7 @@ def _indented_config(config: Config, indent: str) -> Config:
         wrap_length=max(config.wrap_length - len(indent), 0),
         lines_after_imports=1,
         import_headings=config.import_headings if config.indented_import_headings else {},
+        import_footers=config.import_footers if config.indented_import_headings else {},
     )
 
 
